Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(4098)

Unified Diff: chrome/browser/ui/extensions/shell_window.h

Issue 10536093: TabContentsWrapper -> TabContents, part 39. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 8 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/ui/extensions/application_launch.cc ('k') | chrome/browser/ui/extensions/shell_window.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/ui/extensions/shell_window.h
diff --git a/chrome/browser/ui/extensions/shell_window.h b/chrome/browser/ui/extensions/shell_window.h
index 20c85c819ea3715346cd9ad650d5201e2ebb4af3..d44493dac7d5ced3d7bf82a289123bb2ee8e4fd6 100644
--- a/chrome/browser/ui/extensions/shell_window.h
+++ b/chrome/browser/ui/extensions/shell_window.h
@@ -20,7 +20,6 @@ class ExtensionWindowController;
class GURL;
class Profile;
class TabContents;
-typedef TabContents TabContentsWrapper;
namespace content {
class WebContents;
@@ -128,8 +127,8 @@ class ShellWindow : public content::NotificationObserver,
const extensions::Extension* extension_;
const SessionID session_id_;
- scoped_ptr<TabContentsWrapper> contents_wrapper_;
- // web_contents_ is owned by contents_wrapper_.
+ scoped_ptr<TabContents> contents_;
+ // web_contents_ is owned by contents_.
content::WebContents* web_contents_;
content::NotificationRegistrar registrar_;
ExtensionFunctionDispatcher extension_function_dispatcher_;
« no previous file with comments | « chrome/browser/ui/extensions/application_launch.cc ('k') | chrome/browser/ui/extensions/shell_window.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698